##  Updates to the SAP Reference Architecture
The SAP reference architecture data is continuously improved and updated. Since the reference catalog uses this data, these updates also appear in SAP LeanIX. Here’s how the update process works based on the scope of changes:
  * Minor changes: For fact sheets linked to reference business capabilities where only minor changes occurred (such as changes in name or description), the link is automatically updated to the latest version without overwriting any fact sheet data.
  * Major changes: For fact sheets linked to business capabilities where major changes occurred, you can review the changes and manually update the link to the latest version. You can update links in bulk or for individual fact sheets, as described in the following sections. Major changes involve changes to the suggested SAP solutions, such as:
    * New or removed solution options
    * New or removed applications within one solution option
